<?php
/**
 * Header elements
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

if ( ! class_exists( 'Technologist_Header' ) ) {
	/**
	 * Maine class for Header elements.
	 */
	class Technologist_Header extends Technologist_Base {

		/**
		 * Constructor
		 */
		public function __construct() {

			$this->add_action( 'technologist_header_search', 'get_search_box', 10, 1 );
			$this->add_action( 'technologist_trending_posts', 'get_trending_posts', 10 );
		}

		/**
		 * Header Search icon.
		 *
		 * @param string $part search box parts.
		 */
		public function get_search_box( $part = 'icon' ) {

			if ( ! technologist_get_settings( 'hide_search_box' ) ) {
				return;
			}

			if ( 'icon' === $part ) {

				echo '<div class="header-search-icon">';
					Technologist_Images::get_svg( 'search' );
				echo '</div>';

			}

			if ( 'form' === $part ) {

				echo '<div class="full-overlay"></div>';
				echo '<div class="header-search-box">';
					get_search_form();
				echo '</div>';

			}

		}

		/**
		 * Trending Posts.
		 */
		public function get_trending_posts() {

			if ( ! technologist_get_settings( 'trending_posts' ) ) {
				return;
			}

			$post_num = technologist_get_settings( 'trending_post_num' );
			$category = technologist_get_settings( 'trending_category' );

			if ( 'latest' === $category ) {
				$category = '';
			}

			$args = [
				'post_type'      => 'post',
				'post_status'    => 'publish',
				'posts_per_page' => $post_num,
			];

			if ( $category ) {
				$args['category__in'] = $category;
			}

			$query = new WP_Query( $args );
			?>
			<div class="trending-ticker">

				<div class="container">

					<?php technologist_section_title( 'ticker_title', 'ticker-title' ); ?>

					<div class="ticker-posts">

						<ul>

						<?php
						while ( $query->have_posts() ) :
							$query->the_post();
							?>

							<li><?php the_title( sprintf( '<a href="%s" title="%s">', esc_url( get_permalink() ), get_the_title() ), '</a>' ); ?></li>

							<?php
						endwhile;

						wp_reset_postdata();
						?>

						</ul>

					</div>

				</div>

			</div>
			<?php
		}

	}
}

/**
 * Init
 */
new Technologist_Header();
