<?php
/**
 * Set technologist layout according to options
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Technologist_Layout extends Technologist_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'technologist_before_wrapper', 'add_header' );
		$this->add_action( 'technologist_before_content', 'single_featured_section' );
		$this->add_action( 'technologist_before_article', 'add_breadcrumb' );
		$this->add_action( 'technologist_before_footer', 'full_related_posts' );
	}


	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = [
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		];
		$layout = technologist_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single featured section
	 */
	public function single_featured_section() {

		$header_animation = technologist_get_post_header_effect();

		?>
		<div class="single-featured-wrap <?php echo $header_animation ? esc_html( $header_animation ) : ''; ?>">

			<?php $this->single_post_header_thumb(); ?>
			<?php $this->single_featured_header(); ?>

		</div>
		<?php

	}

	/**
	 * Single featured header
	 */
	public function single_featured_header() {
		if ( ! is_single() ) {
			return;
		}
		?>

		<header class="single-full-header clearfix">

			<div class="container">
				<?php technologist_the_post_meta( 'single', 'top' ); ?>

				<?php technologist_the_post_meta( 'single', 'bottom' ); ?>

				<?php technologist_post_title( 'single' ); ?>
			</div>


		</header><!--.single-full-header-->

		<?php

	}

	/**
	 * Add Breadcrumb section
	 */
	public function add_breadcrumb() {

		if ( is_home() || ! technologist_get_settings( 'show_breadcrumb' ) ) {
			return;
		}

		echo '<div class="breadcrumbs-wrapper">';
		echo '<div class="container">';
			technologist_breadcrumbs();
		echo '</div>';
		echo '</div>';
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		if ( ! has_post_thumbnail() ) {
			return;
		}

		$attr = [
			'title' => get_the_title(),
			'alt'   => get_the_title(),
			'class' => 'single-featured-image',
		];

		if ( ! technologist_get_post_header_effect() && technologist_get_settings( 'show_single_featured' ) ) {
			the_post_thumbnail( 'full', $attr );
		}

		technologist_single_featured_image_effect();

	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts() {

		if ( 'full' !== technologist_get_settings( 'related_posts_position' ) || ! is_singular( 'post' ) ) {
			return;
		}
		technologist_related_posts();

	}

}

// Init.
new Technologist_Layout();
