<?php
/**
 * Script enqueueing manager.
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

/**
 * Script enqueueing manager.
 */
class Technologist_Scripts extends Technologist_Base {

	/**
	 * The Constructor
	 */
	public function __construct() {

		if ( ! is_admin() && ! in_array( $GLOBALS['pagenow'], [ 'wp-login.php', 'wp-register.php' ] ) ) {

			$this->add_action( 'wp_enqueue_scripts', 'enqueue_scripts' );

			if ( technologist_get_settings( 'optimize_wc' ) ) {

				$this->add_action( 'wp_enqueue_scripts', 'remove_woocommerce_scripts', 99 );

				// Remove WooCommerce generator tag.
				remove_action( 'wp_head', 'wc_generator_tag' );
			}

			if ( technologist_get_settings( 'async_js' ) ) {
				$this->add_filter( 'script_loader_tag', 'add_async', 10, 2 );
			}

			if ( technologist_get_settings( 'remove_ver_params' ) ) {
				$this->add_filter( 'script_loader_src', 'remove_version', 99 );
				$this->add_filter( 'style_loader_src', 'remove_version', 99 );
			}
		}
	}

	/**
	 * Takes care of enqueueing all our scripts.
	 */
	public function enqueue_scripts() {
		$this->styles();
		$this->scripts();
	}

	/**
	 * Enqueue CSS files
	 */
	private function styles() {
		$version            = technologist()->get_version();
		$template_directory = get_template_directory_uri();

		// style.css file.
		wp_enqueue_style( 'technologist-theme', $template_directory . '/style.css', [], $version );

		$deps = 'technologist-theme';

		// Font Awesome.
		$this->font_styles();
		wp_enqueue_style( 'fontawesome', $template_directory . '/css/font-awesome.min.css', $deps, '4.7.0' );

		// Slider.
		wp_register_style( 'owl-carousel', $template_directory . '/css/owl.carousel.css', $deps, $version );

		// Responsive.
		if ( technologist_get_settings( 'mts_responsive', false ) ) {
			wp_enqueue_style( 'technologist-responsive', $template_directory . '/css/technologist-responsive.css', $deps, $version );
		}

		// WooCommerce.
		if ( technologist_is_woocommerce_active() ) {
			wp_enqueue_style( 'technologist-woocommerce', $template_directory . '/css/technologist-woocommerce.css', 'woocommerce', $version );
		}

		// Lightbox.
		if ( technologist_get_settings( 'enable_lightbox' ) ) {
			wp_enqueue_style( 'magnificPopup', $template_directory . '/css/magnific-popup.css', $deps, $version );
		}

	}

	/**
	 * Enqueue JS files
	 */
	private function scripts() {

		$version            = technologist()->get_version();
		$template_directory = get_template_directory_uri();
		$deps               = [ 'jquery' ];

		// The comment-reply script.
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Ad Blocker Detector.
		if ( technologist_get_settings( 'detect_adblocker' ) ) {
			wp_enqueue_script( 'detector', get_template_directory_uri() . '/js/fuckadblock.min.js' );
		}

		// Main theme script.
		wp_register_script( 'technologist_customscript', $template_directory . '/js/technologist-customscripts.js', $deps, $version, true );

		// Localize for Responsive Menu, header layout and Back to top icon.
		$nav_menu       = 'primary';
		$top_icon_color = technologist_get_settings( 'top_button_color' );

		if ( ! empty( technologist_get_settings( 'dropdown_menu' ) ) ) {
			$nav_menu = 'both';
		}
		wp_localize_script( 'technologist_customscript', 'technologist_customscript', [
			'nav_menu'   => $nav_menu,
			'responsive' => ( empty( technologist_get_settings( 'mts_responsive' ) ) ? false : true ),
			'layout'     => technologist_get_settings( 'header_styles' ),
			'top_icon'   => technologist_get_settings( 'top_icon' ),
			'top_text'   => technologist_get_settings( 'top_text' ),
		] );
		wp_enqueue_script( 'technologist_customscript' );

		// Slider.
		wp_register_script( 'owl-carousel', $template_directory . '/js/owl.carousel.min.js', $deps, $version, true );

		// Animated Single Post or Page header.
		wp_register_script( 'technologist-parallax', $template_directory . '/js/technologist-parallax.js', $deps, $version, true );
		wp_register_script( 'technologist-zoomout', $template_directory . '/js/technologist-zoomout.js', $deps, $version, true );

		if ( is_singular() ) {
			$header_animation = technologist_get_post_header_effect();
			if ( 'parallax' === $header_animation ) {
				wp_enqueue_script( 'technologist-parallax' );
			} elseif ( 'zoomout' === $header_animation ) {
				wp_enqueue_script( 'technologist-zoomout' );
			}
		}

		// Lightbox.
		if ( technologist_get_settings( 'enable_lightbox' ) ) {
			wp_enqueue_script( 'magnificPopup', $template_directory . '/js/jquery.magnific-popup.min.js', $deps, $version, true );
		}

		// Sticky Navigation.
		if ( ! empty( technologist_get_settings( 'sticky_nav' ) ) ) {
			wp_enqueue_script( 'StickyNav', $template_directory . '/js/sticky.js', $deps, $version, true );
		}

		// Ajax Load More and Search Results.
		$pagination_type = technologist_get_settings( 'mts_pagenavigation_type' );

		wp_register_script( 'technologist-ajax', get_template_directory_uri() . '/js/ajax.js', $deps, $version, true );
		wp_register_script( 'historyjs', get_template_directory_uri() . '/js/history.js', $deps, $version, true );

		if ( $pagination_type && $pagination_type >= 2 && ! is_singular() ) {
			wp_enqueue_script( 'technologist-ajax' );
			wp_enqueue_script( 'historyjs' );

			// Add parameters for the JS.
			global $wp_query;
			$max      = $wp_query->max_num_pages;
			$paged    = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
			$autoload = ( '3' === $pagination_type );
			wp_localize_script( 'technologist-ajax', 'technologist_ajax_loadposts', [
				'startPage'     => $paged,
				'maxPages'      => $max,
				'nextLink'      => next_posts( $max, false ),
				'autoLoad'      => $autoload,
				'i18n_loadmore' => __( 'Load More', 'technologist' ),
				'i18n_loading'  => __( 'Loading...', 'technologist' ),
				'i18n_nomore'   => __( 'No more posts', 'technologist' ),
			] );
		}
		if ( ! empty( technologist_get_settings( 'mts_ajax_search' ) ) ) {
			wp_enqueue_script( 'technologist-ajax' );
			wp_localize_script( 'technologist-ajax', 'technologist_ajax_search', [
				'url'         => admin_url( 'admin-ajax.php' ),
				'ajax_search' => '1',
			] );
		}
	}

	/**
	 * Generate needed font
	 *
	 * @return void
	 */
	public function font_styles() {

		$link = get_transient( 'technologist_dynamic_css_typography_link' );
		if ( false === $link ) {
			$fonts = $this->get_google_fonts();

			// If we don't have any fonts then we can exit.
			if ( empty( $fonts ) ) {
				return;
			}

			// Get font-family + subsets.
			$link_fonts = [];
			foreach ( $fonts as $font => $variants ) {

				$variants = implode( ',', $variants );

				$link_font = str_replace( ' ', '+', $font );
				if ( ! empty( $variants ) ) {
					$link_font .= ':' . $variants;
				}
				$link_fonts[] = $link_font;
			}

			$subsets = technologist_get_settings( 'typography-subsets', [] );
			$link    = add_query_arg( [
				'family'  => str_replace( '%2B', '+', rawurlencode( implode( '|', $link_fonts ) ) ),
				'subset'  => rawurlencode( implode( ',', $subsets ) ),
				'display' => 'swap',
			], 'https://fonts.googleapis.com/css' );

			set_transient( 'technologist_dynamic_css_typography_link', $link );
		}

		// Enqueue it.
		wp_enqueue_style( 'technologist_google_fonts', $link, [], null );
	}

	/**
	 * Get typography from theme options
	 *
	 * @return array
	 */
	private function get_google_fonts() {

		$fonts      = [];
		$collection = (array) technologist_get_settings( 'typography-collections', [] );

		$opts = [
			'technologist_logo',
			'primary_navigation_font',
			'search_box_font',  // Search Box.
			'ticker_title_font', // Ticker.
			'ticker_posts_font',
			'pagination_font',
			'load_more_font',
			'archive_categories_font',
			'archive_post_title_font',
			'archive_meta_info_font',
			'archive_post_excerpt_font',
			'breadcrumb_font',
			'single_categories_font',
			'single_title_font',
			'single_meta_info_font',
			'single_page_titles_font',
			'social_share_font', // Share text.
			'single_subscribe_title_font',
			'single_subscribe_text_font',
			'single_subscribe_input_font',
			'single_subscribe_submit_font',
			'single_subscribe_small_text_font',
			'authorbox_title_font',
			'authorbox_author_name_font',
			'authorbox_text_font',
			'content_font',
			'readmore_font',
			'sidebar_title_font',
			'sidebar_buttons_font',
			'mts_widget_links',
			'default_widget_links',
			'sidebar_url_bigthumb',
			'sidebar_font',
			'sidebar_font_bigthumb',
			'sidebar_categories_font',
			'sidebar_postinfo_font',
			'sidebar_postinfo_font_bigthumb',
			'subscribe_widget_title_font', // Subscribe widget.
			'subscribe_widget_text_font',
			'subscribe_widget_fields_font',
			'tabs_title_font',
			'subscribe_title_font',
			'footer_technologist_logo',
			'top_footer_title_font',
			'top_footer_link_font',
			'top_footer_font',
			'footer_metainfo_font',
			'copyrights_font',
			'fields_font',
			'h1_headline',
			'h2_headline',
			'h3_headline',
			'h4_headline',
			'h5_headline',
			'h6_headline',
			'related_posts_categories_font',
			'related_posts_font',
			'related_posts_meta_font',
			'related_posts_excerpt_font',
			'footer_logo_font',
			'top_text_font', // Back to Top.
			'woo_single_title_font', // WooCommerce.
			'woo_single_text_font',
		];

		// Dynamic Tab Fonts.
		$features = technologist_get_settings( 'featured_categories' );
		foreach ( $features as $feature ) {
			if ( ! isset( $feature['unique_id'] ) ) {
				continue;
			}
			$opts[] = 'featured_category_title_font_' . $feature['unique_id'];
			$opts[] = 'categories_font_' . $feature['unique_id'];
			$opts[] = 'meta_info_font_' . $feature['unique_id'];
			$opts[] = 'post_title_font_' . $feature['unique_id'];
			$opts[] = 'post_excerpt_font_' . $feature['unique_id'];

			if ( ! in_array( $feature['blog_layout'], [ 'layout-1', 'layout-3' ], true ) ) {
				$opts[] = 'small_post_title_font_' . $feature['unique_id'];
			}
			if ( ! in_array( $feature['blog_layout'], [ 'layout-3' ], true ) ) {
				$opts[] = 'small_categories_font_' . $feature['unique_id'];
				$opts[] = 'small_meta_info_font_' . $feature['unique_id'];
			}
		}

		foreach ( $opts as $key ) {
			$val = technologist_get_settings( $key, false );

			if ( $val ) {

				// Add to collection.
				$collection[] = $val;
			}
		}

		foreach ( (array) $collection as $font ) {

			$variant = '';

			if ( isset( $font['css-selectors'] ) && empty( trim( $font['css-selectors'] ) ) ) {
				continue;
			}

			if ( empty( $font['font-family'] ) ) {
				continue;
			}

			$variant = empty( $font['font-weight'] ) || 'normal' === $font['font-weight'] ? '400' : $font['font-weight'];

			// Add "i" to font-weight to make italics properly load.
			if ( isset( $font['font-style'] ) && 'italic' === $font['font-style'] ) {
				$variant .= 'i';
			}

			// Add the requested google-font.
			if ( ! isset( $fonts[ $font['font-family'] ] ) ) {
				$fonts[ $font['font-family'] ] = [];
			}
			if ( ! in_array( $variant, $fonts[ $font['font-family'] ], true ) ) {
				$fonts[ $font['font-family'] ][] = $variant;
			}
		}

		return $fonts;
	}

	/**
	 * Add async to technologist javascript file for performance
	 *
	 * @param string $tag    The script tag.
	 * @param string $handle The script handle.
	 */
	public function add_async( $tag, $handle ) {

		$to_match = [ 'technologist' ];
		return in_array( $handle, $to_match ) ? str_replace( ' src', ' async src', $tag ) : $tag;
	}

	/**
	 * Remove version param from script or style source url
	 *
	 * @param  string $src Script loader source path.
	 */
	public function remove_version( $src ) {

		$parts = explode( '?ver', $src );
		return $parts[0];
	}

	/**
	 * Remove WooCommerce Scripts and Styles from unneeded pages.
	 */
	public function remove_woocommerce_scripts() {

		// First check that woo exists to prevent fatal errors.
		if ( function_exists( 'is_woocommerce' ) ) {

			// Dequeue scripts and styles.
			if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() && ! is_account_page() ) {
				wp_dequeue_script( 'technologist-woocommerce' );
				wp_dequeue_style( 'woocommerce-layout' );
				wp_dequeue_style( 'woocommerce-smallscreen' );
				wp_dequeue_style( 'woocommerce-general' );
				wp_dequeue_style( 'wc-bto-styles' );
				wp_dequeue_script( 'wc-add-to-cart' );
				wp_dequeue_script( 'wc-cart-fragments' );
				wp_dequeue_script( 'woocommerce' );
				wp_dequeue_script( 'jquery-blockui' );
				wp_dequeue_script( 'jquery-placeholder' );
			}
		}
	}
}

/**
 * Init
 */
new Technologist_Scripts();
