<?php
/**
 * Single Sections
 *
 * @package Technologist
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Technologist_Single_Sections extends Technologist_Base {

	/**
	 * The Constructor
	 */
	public function __construct() {
		$this->add_action( 'technologist_single_sections', 'render', 10 );
	}

	/**
	 * Render function
	 */
	public function render() {

		$single_layout = technologist_get_settings( 'mts_single_post_layout' );
		?>

		<article class="<?php technologist_article_class(); ?>">

			<?php
			$sidebar = 'nosidebar';
			if ( 'mts_nosidebar' !== mts_custom_sidebar() ) {
				$sidebar = technologist_custom_sidebar_layout();
			}
			?>

			<div id="content_box" class="<?php echo $sidebar; //phpcs:ignore ?>">
				<?php
				// Elementor 'single' location.
				if ( ! technologist_is_elementor( 'single' ) ) {

					if ( have_posts() ) :
						while ( have_posts() ) :
							the_post();

							?>
							<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
								<?php

								// Single post parts ordering.
								$single_post_parts = [
									'content'   => 'content',
									'tags'      => 'tags',
									'subscribe' => 'subscribe',
									'author'    => 'author',
									'related'   => 'related',
								];

								if ( ( null !== $single_layout ) && is_array( $single_layout ) && array_key_exists( 'enabled', $single_layout ) ) {
									$single_post_parts = $single_layout['enabled'];
								}

								foreach ( $single_post_parts as $part => $label ) {
									switch ( $part ) {
										// Content area.
										case 'content':
											$this->single_post();
											break;

										// Tags.
										case 'tags':
											$this->single_tag_section();
											break;

										// Author box.
										case 'author':
											$this->single_author_section();
											break;

										// Related Posts.
										case 'related':
											if ( 'default' === technologist_get_settings( 'related_posts_position' ) ) {
												technologist_related_posts();
											}
											break;

										// Subscribe box.
										case 'subscribe':
											$this->single_subscribe_box();
											break;
									}
								}
								?>
							</div><!--.g post-->
							<?php
							// Comment area.
							comments_template();

						endwhile;
						wp_reset_postdata();
					endif; /* end loop */

				}
				?>
			</div>
		</article>
		<?php
	}

	/**
	 * Single post structure
	 */
	public function single_post() {
		?>
		<div class="single_post">

			<div class="post-single-content box mark-links entry-content">

				<?php
				$this->single_post_ads( 'above' );

				$this->single_post_content();

				$this->single_post_pagination();

				$this->single_post_ads( 'below' );

				$this->single_post_social_icons( 'below' );
				?>

			</div><!--.post-single-content-->

		</div><!--.single_post-->
		<?php
	}

	/**
	 * Single content
	 */
	public function single_post_content() {

		$this->single_post_social_icons( 'above' );

		echo '<div class="thecontent">';
			the_content();
		echo '</div>';

	}

	/**
	 * Single post pagination
	 */
	public function single_post_pagination() {

		// Single Post Pagination.
		$args = [
			'before'           => '<div class="pagination">',
			'after'            => '</div>',
			'link_before'      => '<span class="current"><span class="currenttext">',
			'link_after'       => '</span></span>',
			'next_or_number'   => 'next_and_number',
			'nextpagelink'     => '<i class="fa fa-angle-right"></i>',
			'previouspagelink' => '<i class="fa fa-angle-left"></i>',
			'pagelink'         => '%',
			'echo'             => 1,
		];
		wp_link_pages( $args );

	}

	/**
	 * Single tag section
	 */
	public function single_tag_section() {

		technologist_post_tags( '<div class="tags">', '' );
	}


	/**
	 * Single Author section
	 */
	public function single_author_section() {

		$image_size = technologist_get_settings( 'author_image_size' );

		?>
		<div class="postauthor">

			<?php
			// Author box title.
			technologist_section_title( 'author_box_title' );

			// Author gravatar.
			if ( technologist_get_settings( 'author_box_image' ) && function_exists( 'get_avatar' ) ) {
				echo get_avatar( get_the_author_meta( 'email' ), $image_size ? $image_size : '160' ); // Gravatar size.
			}
			?>
			<div class="content-wrap">
				<?php $this->get_author_designation(); ?>
				<h5 class="vcard author">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="fn">
						<?php the_author_meta( 'display_name' ); ?>
					</a>
				</h5>
				<?php $this->get_author_social_icons(); ?>
				<p><?php the_author_meta( 'description' ); ?></p>
			</div>
		</div>
		<?php
	}

	/**
	 * Author box designation
	 */
	public function get_author_designation() {
		echo '<div class="designation">' . esc_html( get_the_author_meta( 'designation' ) ) . '</div>';
	}

	/**
	 * Author box social icons
	 */
	public function get_author_social_icons() {

		if ( ! technologist_get_settings( 'authorbox_social_share' ) ) {
			return;
		}

		$author_meta = [
			'facebook'    => get_the_author_meta( 'facebook' ),
			'twitter'     => get_the_author_meta( 'twitter' ),
			'linkedin'    => get_the_author_meta( 'linkedin' ),
			'instagram'   => get_the_author_meta( 'instagram' ),
			'pinterest'   => get_the_author_meta( 'pinterest' ),
			'stumbleupon' => get_the_author_meta( 'stumbleupon' ),
		];

		echo '<div class="author-social clearfix">';
		foreach ( $author_meta as $key => $meta ) {
			if ( $meta ) {
				printf(
					'<a href="%1$s" class="%2$s"><i class="fa fa-%2$s"></i></a>',
					esc_html( $meta ),
					esc_html( $key )
				);
			}
		}
		echo '</div>';
	}

	/**
	 * Single Subscribe box
	 */
	public function single_subscribe_box() {
		if ( is_active_sidebar( 'single-subscribe' ) ) {
			?>
				<div class="single-subscribe clear">
					<?php dynamic_sidebar( 'single-subscribe' ); ?>
				</div>
			<?php
		}
	}

	/**
	 * Single Ads
	 *
	 * @param string $location ad location above|below.
	 */
	public function single_post_ads( $location ) {

		$top_ad         = technologist_get_settings( 'mts_posttop_adcode' );
		$top_ad_time    = technologist_get_settings( 'mts_posttop_adcode_time' );
		$bottom_ad      = technologist_get_settings( 'mts_postend_adcode' );
		$bottom_ad_time = technologist_get_settings( 'mts_postend_adcode_time' );

		// Above Content Ad Code.
		if ( ! empty( $top_ad ) && 'above' === $location ) {
			$toptime = ! empty( $top_ad_time ) ? $top_ad_time : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$toptime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="topad">
					<?php echo do_shortcode( $top_ad ); ?>
				</div>
				<?php
			}
		}
		// Below Content Ad Code.
		if ( ! empty( $bottom_ad ) && 'below' === $location ) {
			$endtime = ! empty( $bottom_ad_time ) ? $bottom_ad_time : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$endtime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="bottomad">
					<?php echo do_shortcode( $bottom_ad ); ?>
				</div>
				<?php
			}
		}
	}

	/**
	 * Single Social icons
	 *
	 * @param string $location social icons location above|below|floating.
	 */
	public function single_post_social_icons( $location ) {

		$position = technologist_get_settings( 'mts_social_button_position' );

		// Social Share icons above content.
		if ( $position && ( 'top' === $position || 'both' === $position ) && 'above' === $location ) {
			echo '<div class="share-wrap top">';
				echo '<span class="share-text">' . esc_html__( 'Share this post', 'technologist' ) . '</span>';
				technologist_social_buttons( 'top' );
			echo '</div>';
		}
		// Social Share icons below content.
		if ( $position && ( 'bottom' === $position || 'both' === $position ) && 'below' === $location ) {
			echo '<div class="share-wrap bottom">';
				echo '<span class="share-text">' . esc_html__( 'Share this post', 'technologist' ) . '</span>';
				technologist_social_buttons( 'bottom' );
			echo '</div>';
		}
		// Social Share icons floating.
		if ( $position && 'floating' === $position && 'above' !== $location ) {
			technologist_social_buttons();
		}
	}

}

/**
 * Init
 */
new Technologist_Single_Sections();
