<?php
/**
 * Archive Pages
 *
 * @package Technologist
 */

$menus['blog-archive'] = [
	'icon'  => 'fa-archive',
	'title' => esc_html__( 'Archives', 'technologist' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the archive pages.', 'technologist' ),
];

$sections['blog-archive'] = [
	[
		'id'    => 'archive_post_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Archive Posts Settings', 'technologist' ),
	],
	[
		'id'       => 'archive_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Post Meta Info', 'technologist' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on single page', 'technologist' ),
		'options'  => [
			'category' => esc_html__( 'Category', 'technologist' ),
			'author'   => esc_html__( 'Author Name', 'technologist' ),
			'date'     => esc_html__( 'Date', 'technologist' ),
			'comment'  => esc_html__( 'Comments', 'technologist' ),
		],
		'std'      => [
			'category',
			'author',
			'date',
		],
	],

	[
		'id'       => 'archive_show_excerpt',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show/Hide Excerpt', 'technologist' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide excerpt of post.', 'technologist' ),
		'std'      => '0',
	],
	[
		'id'         => 'archive_excerpt_length',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'technologist' ),
		'sub_desc'   => esc_html__( 'Enter excerpt length to show in the archive pages.', 'technologist' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '20',
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'archive_show_excerpt',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'       => 'archive_categories_bg',
		'type'     => 'color',
		'title'    => esc_html__( 'Categories Background Color', 'technologist' ),
		'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'technologist' ),
		'std'      => '#e5e9ec',
	],
	[
		'id'       => 'archive_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'technologist' ),
		'sub_desc' => esc_html__( 'Enter border radius in px for post thumbnail.', 'technologist' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '8',
	],
	[
		'id'    => 'archive_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography Settings', 'technologist' ),
	],
	[
		'id'    => 'archive_categories_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Categories Typography', 'technologist' ),
		'std'   => [
			'preview-text'   => 'Categories Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '600',
			'font-size'      => '13px',
			'color'          => '#19202d',
			'letter-spacing' => technologist_letter_spacing( '13px', '154' ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.archive .post-info.top a, .search .post-info.top a',
		],
	],
	[
		'id'    => 'archive_post_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Title Font', 'technologist' ),
		'std'   => [
			'preview-text'   => 'Post Title Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '24px',
			'margin-top'     => '14px',
			'color'          => '#19202d',
			'letter-spacing' => technologist_letter_spacing( '24px', '-19' ),
			'css-selectors'  => '.latestPost .title a, .archive .latestPost .title a, .search .latestPost .title a, .archive [class^="more-page"] .latestPost .title a, .search [class^="more-page"] .latestPost .title a',
		],
	],
	[
		'id'    => 'archive_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Meta Info Typography', 'technologist' ),
		'std'   => [
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '13px',
			'color'          => '#878d94',
			'margin-top'     => '7px',
			'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
			'css-selectors'  => '.archive .latestPost .post-info.bottom, .search .latestPost .post-info.bottom, .archive .latestPost .post-info.bottom a, .search .latestPost .post-info.bottom a',
		],
	],
	[
		'id'    => 'archive_post_excerpt_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Excerpt Font', 'technologist' ),
		'std'   => [
			'preview-text'   => 'Post Excerpt Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '13px',
			'margin-top'     => '5px',
			'color'          => '#19202d',
			'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
			'css-selectors'  => '.archive .latestPost .front-view-content, .search .latestPost .front-view-content, .archive [class^="more-page"] .latestPost .front-view-content, .search [class^="more-page"] .latestPost .front-view-content',
		],
	],
];
