<?php
/**
 * HomePage Pagination
 *
 * @package Technologist
 */

$menus['blog-pagination'] = [
	'icon'  => 'fa-ellipsis-h',
	'title' => esc_html__( 'Pagination', 'technologist' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'technologist' ),
];

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	],
];

// Dependency check the load more button.
$loadmore_button_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	],
];

$sections['blog-pagination'] = [

	[
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'technologist' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'technologist' ),
		'options'  => [
			'0' => esc_html__( 'Default (Next / Previous)', 'technologist' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'technologist' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'technologist' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'technologist' ),
		],
		'std'      => '2',
	],

	[
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'technologist' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'technologist' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'technologist' ),
			'center' => esc_html__( 'Center', 'technologist' ),
			'right'  => esc_html__( 'Right', 'technologist' ),
		],
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'technologist' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'technologist' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'technologist' ),
			'center' => esc_html__( 'Center', 'technologist' ),
			'right'  => esc_html__( 'Right', 'technologist' ),
			'full'   => esc_html__( 'Full Width', 'technologist' ),
		],
		'std'        => 'full',
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'technologist' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'pattern',
			'color'         => '#dfe4e7',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Load More background color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'technologist' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'pattern',
			'color'         => '#19202d',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
		],
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background hover color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'technologist' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'pattern',
			'color'         => '#5c6370',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#000000',
				'to'        => '#ffffff',
				'direction' => '0deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_active_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background Active color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select pagination background active color.', 'technologist' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'pattern',
			'color'         => '#19202d',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#000000',
				'to'        => '#ffffff',
				'direction' => '0deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Load More background hover color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select load more background hover color.', 'technologist' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'pattern',
			'color'         => '#5c6370',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
		],
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'technologist' ),
		'std'        => '#19202d',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'technologist' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'technologist' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'technologist' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'technologist' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'technologist' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'technologist' ),
		'std'      => [
			'top'    => '0',
			'right'  => technologist_px2rem( '5px' ),
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'technologist' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'technologist' ),
		'std'        => [
			'top'    => technologist_px2rem( '12px' ),
			'right'  => technologist_px2rem( '11px' ),
			'bottom' => technologist_px2rem( '12px' ),
			'left'   => technologist_px2rem( '11px' ),
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'technologist' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'technologist' ),
		'std'        => [
			'top'    => technologist_px2rem( '16px' ),
			'right'  => technologist_px2rem( '20px' ),
			'bottom' => technologist_px2rem( '16px' ),
			'left'   => technologist_px2rem( '20px' ),
		],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Pagination border radius', 'technologist' ),
		'sub_desc' => esc_html__( 'Update pagination border radius in px.', 'technologist' ),
		'std'      => '8',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'pagenavigation_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'technologist' ),
		'sub_desc' => esc_html__( 'Select border', 'technologist' ),
	],
	[
		'id'         => 'pagination_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Pagination Font', 'technologist' ),
		'color'      => false,
		'std'        => [
			'preview-text'  => 'Pagination',
			'preview-color' => 'light',
			'font-family'   => 'Big Shoulders Display',
			'font-weight'   => '600',
			'font-size'     => '16px',
			'css-selectors' => '.pagination',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Load More Font', 'technologist' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Load More',
			'preview-color'  => 'light',
			'font-family'    => 'Big Shoulders Display',
			'font-weight'    => '600',
			'font-size'      => '16px',
			'letter-spacing' => technologist_letter_spacing( '16px', '125' ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '#load-posts a, .pagination .nav-next a, .pagination .nav-previous a',
		],
		'dependency' => $loadmore_button_dependency,
	],

];
