<?php
/**
 * HomePage Posts
 *
 * @package Technologist
 */

$features = technologist_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = $feature['mts_featured_title'] ? $feature['mts_featured_title'] : 'New Section';
	$posts_layout = $feature['blog_layout'] ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = [
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'technologist' ) ), $title ),
	];

	// Dependency check that back to top option is enable.
	$post_title_dependency = [
		'relation' => 'and',
		[
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];
	$read_more_dependency  = [
		'relation' => 'and',
		[
			'field'      => 'enable_readmore_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$sections[ 'blog-' . $unique_id ] = [

		/**
		 * Layout Default Settings
		 *
		 * @package Technologist
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'technologist' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_text_' . $unique_id,
			'type'       => 'heading_text',
			'title'      => esc_html__( 'Custom Title', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set Custom Title for the Posts section. Leave blank to show category title.', 'technologist' ),
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'technologist' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'technologist' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'technologist' ),
				'center' => esc_html__( 'Center', 'technologist' ),
				'right'  => esc_html__( 'Right', 'technologist' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '#19202d',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'technologist' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'technologist' ),
			'std'        => [
				'top'    => '2px',
				'right'  => technologist_px2rem( '20px' ),
				'bottom' => '2px',
				'left'   => technologist_px2rem( '20px' ),
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'technologist' ),
			'sub_desc'   => esc_html__( 'Select border', 'technologist' ),
			'dependency' => $post_title_dependency,
			'std'        => [
				'style'     => 'solid',
				'color'     => '#d5dadd',
				'size'      => '1',
				'direction' => 'bottom',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'            => 'featured_category_title_font_' . $unique_id,
			'type'          => 'typography',
			'title'         => esc_html__( 'Section Title Typography', 'technologist' ),
			'margin-top'    => false,
			'margin-bottom' => false,
			'std'           => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Big Shoulders Display',
				'font-weight'    => '600',
				'font-size'      => '20px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '20px', '125' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency'    => $post_title_dependency,
		] : null,

		// Meta info.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'technologist' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'technologist' ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s category', 'technologist' ) ), $title ),
			'options'  => [
				'category' => esc_html__( 'Category', 'technologist' ),
				'author'   => esc_html__( 'Author Name', 'technologist' ),
				'date'     => esc_html__( 'Date', 'technologist' ),
				'comment'  => esc_html__( 'Comments', 'technologist' ),
			],
			'std'      => [
				'category',
				'author',
				'date',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'categories_bg_color_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Categories Background Color', 'technologist' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'technologist' ),
			'std'      => '#e5e9ec',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Categories Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '600',
				'font-size'      => '13px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '13px', '154' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.top a',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'color'          => '#878d94',
				'margin-top'     => '7px',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.bottom, .layout-' . $unique_id . ' .latestPost .post-info.bottom a',
			],
		] : null,
		// Post Container.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'technologist' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_image_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Border Radius', 'technologist' ),
			'sub_desc' => esc_html__( 'Enter border radius in px for post thumbnail.', 'technologist' ),
			'args'     => [ 'type' => 'number' ],
			'std'      => '8',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'show_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Excerpt', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide excerpt of post.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'technologist' ),
			'sub_desc' => esc_html__( 'Select border', 'technologist' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'technologist' ),
			'sub_desc' => esc_html__( 'Post margin.', 'technologist' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => technologist_px2rem( '90px' ),
				'bottom' => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'technologist' ),
			'sub_desc' => esc_html__( 'Post padding.', 'technologist' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '24px',
				'margin-top'     => '12px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '24px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'margin-top'     => '5px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Technologist
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'technologist' ),
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'featured_category_title_text_' . $unique_id,
			'type'       => 'heading_text',
			'title'      => esc_html__( 'Custom Title', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set Custom Title for the Posts section. Leave blank to show category title.', 'technologist' ),
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'technologist' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'technologist' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'technologist' ),
				'center' => esc_html__( 'Center', 'technologist' ),
				'right'  => esc_html__( 'Right', 'technologist' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '#19202d',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'technologist' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'technologist' ),
			'std'        => [
				'top'    => '2px',
				'right'  => technologist_px2rem( '20px' ),
				'bottom' => '2px',
				'left'   => technologist_px2rem( '20px' ),
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'technologist' ),
			'sub_desc'   => esc_html__( 'Select border', 'technologist' ),
			'dependency' => $post_title_dependency,
			'std'        => [
				'style'     => 'solid',
				'color'     => '#d5dadd',
				'size'      => '1',
				'direction' => 'bottom',
			],
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'            => 'featured_category_title_font_' . $unique_id,
			'type'          => 'typography',
			'title'         => esc_html__( 'Section Title Typography', 'technologist' ),
			'margin-top'    => false,
			'margin-bottom' => false,
			'std'           => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Big Shoulders Display',
				'font-weight'    => '600',
				'font-size'      => '20px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '20px', '125' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency'    => $post_title_dependency,
		] : null,

		// Meta info.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'technologist' ),
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'technologist' ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s category', 'technologist' ) ), $title ),
			'options'  => [
				'category' => esc_html__( 'Category', 'technologist' ),
				'author'   => esc_html__( 'Author Name', 'technologist' ),
				'date'     => esc_html__( 'Date', 'technologist' ),
				'comment'  => esc_html__( 'Comments', 'technologist' ),
			],
			'std'      => [
				'category',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'categories_bg_color_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Categories Background Color', 'technologist' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'technologist' ),
			'std'      => '#ffffff',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Categories Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '600',
				'font-size'      => '13px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '13px', '154' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.top a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'color'          => '#ffffff',
				'margin-top'     => '7px',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'additional-css' => 'opacity: 0.5;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.bottom, .layout-' . $unique_id . ' .latestPost .post-info.bottom a',
			],
		] : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'technologist' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background', 'technologist' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_bg2_color_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Background Color 2', 'technologist' ),
			'sub_desc' => esc_html__( 'Set the second background color for this post layout.', 'technologist' ),
			'std'      => '#edf2f8',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_bg2_height_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Background Color 2 height', 'technologist' ),
			'sub_desc' => esc_html__( 'Set the second background color height from here in percentage(%).', 'technologist' ),
			'args'     => [ 'type' => 'number' ],
			'std'      => '60',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_image_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Border Radius', 'technologist' ),
			'sub_desc' => esc_html__( 'Enter border radius in px for post thumbnail.', 'technologist' ),
			'args'     => [ 'type' => 'number' ],
			'std'      => '8',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'show_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Excerpt', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide excerpt of post.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'technologist' ),
			'sub_desc' => esc_html__( 'Select border', 'technologist' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'technologist' ),
			'sub_desc' => esc_html__( 'Post margin.', 'technologist' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'technologist' ),
			'sub_desc' => esc_html__( 'Post padding.', 'technologist' ),
			'std'      => [
				'top'    => technologist_px2rem( '64px' ),
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '32px',
				'margin-top'     => '10px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '32px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'small_post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Small Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Small Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '24px',
				'margin-top'     => '10px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '24px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.small .title a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'margin-top'     => '5px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Technologist
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'technologist' ),
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'technologist' ),
			'std'      => '1',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'featured_category_title_text_' . $unique_id,
			'type'       => 'heading_text',
			'title'      => esc_html__( 'Custom Title', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set Custom Title for the Posts section. Leave blank to show category title.', 'technologist' ),
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'technologist' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'technologist' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'technologist' ),
				'center' => esc_html__( 'Center', 'technologist' ),
				'right'  => esc_html__( 'Right', 'technologist' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '#19202d',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'technologist' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'technologist' ),
			'std'        => [
				'top'    => '2px',
				'right'  => technologist_px2rem( '20px' ),
				'bottom' => '2px',
				'left'   => technologist_px2rem( '20px' ),
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'technologist' ),
			'sub_desc'   => esc_html__( 'Select border', 'technologist' ),
			'dependency' => $post_title_dependency,
			'std'        => [
				'style'     => 'solid',
				'color'     => '#d5dadd',
				'size'      => '1',
				'direction' => 'bottom',
			],
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'            => 'featured_category_title_font_' . $unique_id,
			'type'          => 'typography',
			'title'         => esc_html__( 'Section Title Typography', 'technologist' ),
			'margin-top'    => false,
			'margin-bottom' => false,
			'std'           => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Big Shoulders Display',
				'font-weight'    => '600',
				'font-size'      => '20px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '20px', '125' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency'    => $post_title_dependency,
		] : null,

		// Meta info.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'technologist' ),
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'technologist' ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s category', 'technologist' ) ), $title ),
			'options'  => [
				'category' => esc_html__( 'Category', 'technologist' ),
				'author'   => esc_html__( 'Author Name', 'technologist' ),
				'date'     => esc_html__( 'Date', 'technologist' ),
				'comment'  => esc_html__( 'Comments', 'technologist' ),
			],
			'std'      => [
				'author',
				'date',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'categories_bg_color_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Categories Background Color', 'technologist' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'technologist' ),
			'std'      => '#ffffff',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Categories Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '600',
				'font-size'      => '10px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '10px', '154' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.top a',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'color'          => '#878d94',
				'margin-top'     => '1px',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info.bottom, .layout-' . $unique_id . ' .latestPost .post-info.bottom a',
			],
		] : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'technologist' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background', 'technologist' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_image_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Border Radius', 'technologist' ),
			'sub_desc' => esc_html__( 'Enter border radius in px for post thumbnail.', 'technologist' ),
			'args'     => [ 'type' => 'number' ],
			'std'      => '8',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'show_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Excerpt', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide excerpt of post.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'technologist' ),
			'sub_desc' => esc_html__( 'Select border', 'technologist' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'technologist' ),
			'sub_desc' => esc_html__( 'Post margin.', 'technologist' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => technologist_px2rem( '90px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'technologist' ),
			'sub_desc' => esc_html__( 'Post padding.', 'technologist' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'margin-top'     => technologist_px2rem( '25px' ),
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '16px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'margin-top'     => '5px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout 3 Settings
		 *
		 * @package Technologist
		 */

		// Section Title.
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'technologist' ),
		] : null,

		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'featured_category_title_text_' . $unique_id,
			'type'       => 'heading_text',
			'title'      => esc_html__( 'Custom Title', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set Custom Title for the Posts section. Leave blank to show category title.', 'technologist' ),
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'technologist' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'technologist' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'technologist' ),
				'center' => esc_html__( 'Center', 'technologist' ),
				'right'  => esc_html__( 'Right', 'technologist' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '#d5dadd',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'technologist' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'technologist' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'technologist' ),
			'std'        => [
				'top'    => '2px',
				'right'  => technologist_px2rem( '20px' ),
				'bottom' => '2px',
				'left'   => technologist_px2rem( '20px' ),
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'technologist' ),
			'sub_desc'   => esc_html__( 'Select border', 'technologist' ),
			'dependency' => $post_title_dependency,
			'std'        => [
				'style'     => 'solid',
				'color'     => '#d5dadd',
				'size'      => '1',
				'direction' => 'bottom',
			],
		] : null,

		( 'layout-3' === $posts_layout ) ? [
			'id'            => 'featured_category_title_font_' . $unique_id,
			'type'          => 'typography',
			'title'         => esc_html__( 'Section Title Typography', 'technologist' ),
			'margin-top'    => false,
			'margin-bottom' => false,
			'std'           => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Big Shoulders Display',
				'font-weight'    => '600',
				'font-size'      => '20px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '20px', '125' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency'    => $post_title_dependency,
		] : null,

		// Meta info.
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'technologist' ),
		] : null,

		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'technologist' ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s category', 'technologist' ) ), $title ),
			'options'  => [
				'category' => esc_html__( 'Category', 'technologist' ),
				'author'   => esc_html__( 'Author Name', 'technologist' ),
				'date'     => esc_html__( 'Date', 'technologist' ),
				'comment'  => esc_html__( 'Comments', 'technologist' ),
			],
			'std'      => [
				'category',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'categories_bg_color_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Categories Background Color', 'technologist' ),
			'sub_desc' => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'technologist' ),
			'std'      => '#ffffff',
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Categories Typography for Big Post', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Categories Font for Big Post',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '600',
				'font-size'      => '13px',
				'color'          => '#19202d',
				'letter-spacing' => technologist_letter_spacing( '13px', '154' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .post-info.top a',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'small_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Categories Typography for Small Posts', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Categories Font for Small Posts',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '600',
				'font-size'      => '10px',
				'color'          => '#8c9096',
				'letter-spacing' => technologist_letter_spacing( '10px', '154' ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.small .post-info.top a',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Meta Info Typography for Big Post', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Meta Info Font for Big Post',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'color'          => '#ffffff',
				'margin-top'     => '2px',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .post-info.bottom, .layout-' . $unique_id . ' .latestPost.big .post-info.bottom a',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'small_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Meta Info Typography for Small Post', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Meta Info Font for Small Post',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'color'          => '#ffffff',
				'margin-top'     => '7px',
				'letter-spacing' => technologist_letter_spacing( '12px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.small .post-info.bottom, .layout-' . $unique_id . ' .latestPost.small .post-info.bottom a',
			],
		] : null,
		// Post Container.
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'technologist' ),
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background', 'technologist' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'technologist' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '#19202d',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'post_image_border_radius_' . $unique_id,
			'type'     => 'text',
			'class'    => 'small-text',
			'title'    => esc_html__( 'Border Radius', 'technologist' ),
			'sub_desc' => esc_html__( 'Enter border radius in px for post thumbnail.', 'technologist' ),
			'args'     => [ 'type' => 'number' ],
			'std'      => '8',
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'show_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Excerpt', 'technologist' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide excerpt of post.', 'technologist' ),
			'std'      => '0',
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'technologist' ),
			'sub_desc' => esc_html__( 'Select border', 'technologist' ),
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'technologist' ),
			'sub_desc' => esc_html__( 'Post margin.', 'technologist' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => technologist_px2rem( '90px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'technologist' ),
			'sub_desc' => esc_html__( 'Post padding.', 'technologist' ),
			'std'      => [
				'left'   => '0',
				'top'    => technologist_px2rem( '122px' ),
				'right'  => '0',
				'bottom' => technologist_px2rem( '90px' ),
			],
		] : null,

		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '32px',
				'margin-top'     => '10px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '32px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.big .title a',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'small_post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Small Post Title Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Small Post Title Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'margin-top'     => '8px',
				'color'          => '#ffffff',
				'letter-spacing' => technologist_letter_spacing( '16px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.small .title a',
			],
		] : null,
		( 'layout-3' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'technologist' ),
			'std'   => [
				'preview-text'   => 'Post Excerpt Font',
				'preview-color'  => 'dark',
				'font-family'    => 'Montserrat',
				'font-weight'    => '500',
				'font-size'      => '13px',
				'margin-top'     => '5px',
				'color'          => '#ffffff',
				'line-height'    => '1.4',
				'letter-spacing' => technologist_letter_spacing( '13px', '-19' ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Technologist
		 */
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'technologist' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'technologist' ),
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'technologist' ),
			'sub_desc' => esc_html__( 'Post margin.', 'technologist' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'technologist' ),
			'sub_desc' => esc_html__( 'Post padding.', 'technologist' ),
			'std'      => [
				'top'    => technologist_px2rem( '50px' ),
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
		] : null,

	];
endforeach;
