<?php
/**
 * Blog Tab
 *
 * @package Technologist
 */

$menus['blog'] = [
	'icon'  => 'fa-list-alt',
	'title' => esc_html__( 'Blog', 'technologist' ),
];

$layout_dependency = [
	'relation' => 'and',
	[
		'field'      => 'blog_layout',
		'value'      => 'layout-html',
		'comparison' => '!=',
	],
];
$latest_dependency   = $layout_dependency;
$latest_dependency[] = [
	'field'      => 'mts_featured_category',
	'value'      => 'latest',
	'comparison' => '!=',
];

$menus['blog']['child']['blog-general'] = [
	'title' => esc_html__( 'General', 'technologist' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Blog page.', 'technologist' ),
];

$sections['blog-general'] = [

	[
		'id'                => 'featured_categories',
		'type'              => 'group',
		'title'             => esc_html__( 'Blog Sections', 'technologist' ),
		'sub_desc'          => esc_html__( 'Select categories appearing on the homepage.', 'technologist' ),
		'groupname'         => esc_html__( 'Section', 'technologist' ),
		'subfields'         => [
			[
				'id'    => 'mts_featured_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'technologist' ),
			],
			[
				'id'   => 'unique_id',
				'type' => 'text',
				'args' => [
					'type'  => 'hidden',
					'class' => 'hidden',
				],
			],
			[
				'id'       => 'blog_layout',
				'type'     => 'radio_img',
				'title'    => esc_html__( 'Blog Layout', 'technologist' ),
				'sub_desc' => wp_kses( __( 'Choose the <strong>layout</strong> for your blog posts.', 'technologist' ), [ 'strong' => '' ] ),
				'options'  => [
					'layout-default' => [ 'img' => $uri . 'home/layout-default.png' ],
					'layout-1'       => [ 'img' => $uri . 'home/layout-1.png' ],
					'layout-2'       => [ 'img' => $uri . 'home/layout-2.png' ],
					'layout-3'       => [ 'img' => $uri . 'home/layout-3.png' ],
					'layout-html'    => [ 'img' => $uri . 'home/layout-html.png' ],
				],
				'std'      => 'layout-default',
			],
			[
				'id'         => 'mts_featured_category',
				'type'       => 'select',
				'title'      => esc_html__( 'Category', 'technologist' ),
				'sub_desc'   => esc_html__( 'Select a category or the latest posts for this section', 'technologist' ),
				'std'        => 'latest',
				'data'       => 'category_slug',
				'args'       => [
					'include_latest' => 1,
					'hide_empty'     => 0,
				],
				'dependency' => $layout_dependency,
			],
			[
				'id'         => 'mts_featured_category_postsnum',
				'type'       => 'text',
				'class'      => 'small-text',
				'title'      => esc_html__( 'Number of posts', 'technologist' ),
				// translators: Description.
				'sub_desc'   => esc_html__( 'Enter the number of posts to show in this section.' ),
				'args'       => [ 'type' => 'number' ],
				'dependency' => $latest_dependency,
			],
			[
				'id'         => 'featured_latest_num_info',
				'type'       => 'info',
				// 'title'      => esc_html__( 'Number of posts', 'technologist' ),
				// translators: Description.
				'sub_desc'   => sprintf( wp_kses_post( __( '<strong>For Latest Posts</strong>, set the number of posts from here: <a href="%s" target="_blank">Settings&nbsp;&gt;&nbsp;Reading</a>.', 'technologist' ) ), admin_url( 'options-reading.php' ) ),
				'dependency' => [
					'relation' => 'and',
					[
						'field'      => 'mts_featured_category',
						'value'      => 'latest',
						'comparison' => '==',
					],
				],
			],
			[
				'id'         => 'mts_featured_category_excerpt',
				'type'       => 'text',
				'class'      => 'small-text',
				'title'      => esc_html__( 'Excerpt Length', 'technologist' ),
				'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'technologist' ),
				'args'       => [ 'type' => 'number' ],
				'dependency' => $layout_dependency,
			],

		],
		'std'               => [
			'1' => [
				'group_title'                    => '',
				'group_sort'                     => '1',
				'mts_featured_title'             => 'Latest',
				'blog_layout'                    => 'layout-default',
				'mts_featured_category'          => 'latest',
				'mts_featured_category_postsnum' => get_option( 'posts_per_page' ),
				'mts_featured_category_excerpt'  => '20',
				'unique_id'                      => uniqid(),
			],
		],

		'validate_callback' => 'validate_featured_categories',
	],

];
