<?php
/**
 * Single AuthorBox
 *
 * @package Technologist
 */

$menus['single-authorbox'] = [
	'icon'  => 'fa-pencil',
	'title' => esc_html__( 'Author Box', 'technologist' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of Author box in single posts page.', 'technologist' ),
];

$author_image_dependency = [
	'relation' => 'and',
	[
		'field'      => 'author_box_image',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['single-authorbox'] = [

	[
		'id'    => 'authorbox_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Settings', 'technologist' ),
	],
	[
		'id'       => 'authorbox_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Author box Background', 'technologist' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image for subscribe box from here.', 'technologist' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#19202d',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'author_box_title',
		'type'     => 'heading_text',
		'title'    => esc_html__( 'Author Box Title', 'technologist' ),
		'sub_desc' => esc_html__( 'Enter author box title.', 'technologist' ),
		'std'      => [
			'heading' => '',
			'tag'     => 'h4',
		],
	],
	[
		'id'       => 'authorbox_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'technologist' ),
		'sub_desc' => esc_html__( 'Set Author box margin from here.', 'technologist' ),
		'std'      => [
			'top'    => technologist_px2rem( '40px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'authorbox_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'technologist' ),
		'sub_desc' => esc_html__( 'Set Author box padding from here.', 'technologist' ),
		'std'      => [
			'top'    => technologist_px2rem( '40px' ),
			'right'  => technologist_px2rem( '38px' ),
			'bottom' => technologist_px2rem( '37px' ),
			'left'   => technologist_px2rem( '38px' ),
		],
	],
	[
		'id'       => 'authorbox_border',
		'type'     => 'border2',
		'title'    => esc_html__( 'Border', 'technologist' ),
		'sub_desc' => esc_html__( 'Select border', 'technologist' ),
	],
	[
		'id'       => 'authorbox_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'technologist' ),
		'sub_desc' => esc_html__( 'Author box border radius.', 'technologist' ),
		'std'      => '0',
		'args'     => [ 'type' => 'number' ],
	],

	[
		'id'    => 'author_img_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Image Settings', 'technologist' ),
	],
	[
		'id'       => 'author_box_image',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Image', 'technologist' ),
		'sub_desc' => esc_html__( 'Use this button to show/hide author image.', 'technologist' ),
		'std'      => '1',
	],
	[
		'id'         => 'author_image_size',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Image Size', 'technologist' ),
		'sub_desc'   => esc_html__( 'Set author image size in px from here.', 'technologist' ),
		'std'        => '80',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $author_image_dependency,
	],
	[
		'id'         => 'single_author_image_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Margin', 'technologist' ),
		'sub_desc'   => esc_html__( 'Set Author image margin from here.', 'technologist' ),
		'std'        => [
			'top'    => '0',
			'right'  => technologist_px2rem( '30px' ),
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $author_image_dependency,
	],
	[
		'id'         => 'single_author_image_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Border Radius', 'technologist' ),
		'sub_desc'   => esc_html__( 'Author image border radius.', 'technologist' ),
		'std'        => '80',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $author_image_dependency,
	],

	[
		'id'    => 'author_content_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Content Settings', 'technologist' ),
	],
	[
		'id'       => 'authorbox_content_border',
		'type'     => 'border2',
		'title'    => esc_html__( 'Content Border', 'technologist' ),
		'sub_desc' => esc_html__( 'Select border for content area', 'technologist' ),
	],
	[
		'id'       => 'authorbox_social_share',
		'type'     => 'switch',
		'title'    => esc_html__( 'Author Social Icons', 'technologist' ),
		'sub_desc' => esc_html__( 'Enable/Disable author social icons in the author box.', 'technologist' ),
		'std'      => '1',
	],
	[
		'id'    => 'authorbox_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Title Font', 'technologist' ),
		'std'   => [
			'preview-text'  => 'Author Box Title Font',
			'preview-color' => 'dark',
			'font-family'   => 'Montserrat',
			'font-weight'   => '700',
			'font-size'     => '20px',
			'line-height'   => '1',
			'margin-bottom' => technologist_px2rem( '30px' ),
			'color'         => '#ffffff',
			'css-selectors' => '.postauthor h4',
		],
	],
	[
		'id'            => 'authorbox_author_name_font',
		'type'          => 'typography',
		'title'         => esc_html__( 'Author Name Font', 'technologist' ),
		'margin-top'    => false,
		'margin-bottom' => false,
		'std'           => [
			'preview-text'   => 'Author Name Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Montserrat',
			'font-weight'    => '800',
			'font-size'      => '20px',
			'line-height'    => '1',
			'color'          => '#ffffff',
			'additional-css' => 'text-transform: capitalize;',
			'css-selectors'  => '.postauthor h5, .postauthor h5 a',
		],
	],
	[
		'id'    => 'authorbox_text_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Text Font', 'technologist' ),
		'std'   => [
			'preview-text'  => 'Author Text Font',
			'preview-color' => 'dark',
			'font-family'   => 'Montserrat',
			'font-weight'   => '400',
			'font-size'     => '15px',
			'line-height'   => technologist_line_height( '15px', '25' ),
			'margin-top'    => '14px',
			'color'         => '#c5c7ca',
			'css-selectors' => '.postauthor p',
		],
	],

];
