<?php
/**
 * Vendor: WooCommerce
 *
 * @package Technologist
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * WooCommerce override and extra
 */
class Technologist_WooCommerce extends Technologist_Base {

	/**
	 * The Constructor
	 */
	public function __construct() {

		$this->add_filter( 'loop_shop_per_page', 'products_per_page', 99 );
		$this->add_filter( 'loop_shop_columns', 'loop_shop_columns', 99 );
		$this->add_filter( 'woocommerce_output_related_products_args', 'related_products_args', 99 );
		$this->add_filter( 'woocommerce_upsell_display_args', 'related_products_args' );
		$this->add_filter( 'woocommerce_product_thumbnails_columns', 'product_thumbnails_columns' );

	}

	/**
	 * Determine how many products we want to show per page.
	 *
	 * @return int
	 */
	public function products_per_page() {

		$per_page = 12;
		if ( technologist_get_settings( 'woocommerce_shop_items' ) ) {
			$per_page = technologist_get_settings( 'woocommerce_shop_items', 12 );
		}

		return $per_page;
	}

	/**
	 * Determine how many columns.
	 *
	 * @return int
	 */
	public function loop_shop_columns() {

		$columns = 3;
		if ( technologist_get_settings( 'woocommerce_shop_page_columns' ) ) {
			$columns = technologist_get_settings( 'woocommerce_shop_page_columns' );
		}

		return $columns;
	}

	/**
	 * Related Products Args
	 *
	 * @param  array $args related products args.
	 * @since 1.0.0
	 * @return  array $args related products args
	 */
	public function related_products_args( $args ) {

		$args = [
			'posts_per_page' => technologist_get_settings( 'woocommerce_related_items' ),
			'columns'        => technologist_get_settings( 'woocommerce_related_columns' ),
			'orderby'        => 'rand',
		];

		return $args;
	}

	/**
	 * Change the number of product thumbnails to show per row to 4.
	 *
	 * @return int
	 */
	public function product_thumbnails_columns() {
		return 3;
	}

}

// INit.
new Technologist_WooCommerce();
